Cursor

Struct Cursor 

pub struct Cursor<'a>(/* private fields */);
The cursor for querying over the VM space without modifying it.

It exclusively owns a sub-tree of the page table, preventing others from reading or modifying the same sub-tree. Two read-only cursors can not be created from the same virtual address range either.

Implementations

Source

impl Cursor<'_>

pub fn query(&mut self) -> Result<(Range<Vaddr>, Option<VmQueriedItem<'_>>)>

Queries the mapping at the current virtual address.

If the cursor is pointing to a valid virtual address that is locked, it will return the virtual address range and the mapped item.

pub fn find_next(&mut self, len: usize) -> Option<Vaddr>

Moves the cursor forward to the next mapped virtual address.

If there is mapped virtual address following the current address within next len bytes, it will return that mapped address. In this case, the cursor will stop at the mapped address.

Otherwise, it will return None. And the cursor may stop at any address after len bytes.

Panics

Panics if the length is longer than the remaining range of the cursor.

pub fn jump(&mut self, va: Vaddr) -> Result<()>

Jumps to the virtual address.

pub fn virt_addr(&self) -> Vaddr

Gets the virtual address of the current slot.